# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sender.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import aiddl_pb2 as aiddl__pb2
from . import empty_pb2 as empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csender.proto\x12\x17org.aiddl.external.grpc\x1a\x0b\x61iddl.proto\x1a\x0b\x65mpty.proto2O\n\x06Sender\x12\x45\n\x04Send\x12\x1d.org.aiddl.external.grpc.Term\x1a\x1e.org.aiddl.external.grpc.EmptyB\x19\n\x17org.aiddl.external.grpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sender_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027org.aiddl.external.grpc'
  _SENDER._serialized_start=67
  _SENDER._serialized_end=146
# @@protoc_insertion_point(module_scope)
